import curses
from curses import wrapper
from dankbot import DankBot
import time
from threading import Thread

def main(stdscr):
    curses.init_pair(1, curses.COLOR_GREEN, curses.COLOR_BLACK)
    curses.init_pair(2, curses.COLOR_RED, curses.COLOR_BLACK)
    curses.init_pair(3, curses.COLOR_CYAN, curses.COLOR_BLACK)
    curses.init_pair(4, curses.COLOR_YELLOW, curses.COLOR_BLACK)
    curses.init_pair(5, curses.COLOR_RED, curses.COLOR_YELLOW)
    p = 0
    i = 0
    while(p != 78 and p != 110):
        stdscr.clear()
        stdscr.refresh()
        stdscr.addstr(15, 0, f"Please Make Sure That You Are Using Full Screen Before Moving to the next step (Press N)(Iteration {i+1}, p = {p})", curses.color_pair(2))
        i += 1
        p = stdscr.getch()      
    stdscr.clear()
    stdscr.refresh()
    stdscr.addstr(15, ((curses.COLS - 1) // 2) + 19, "       /||\                     /||\\", curses.color_pair(1))
    stdscr.addstr(16, ((curses.COLS - 1) // 2) + 19, "    ///    \\\\\\               ///    \\\\\\", curses.color_pair(1))
    stdscr.addstr(17, ((curses.COLS - 1) // 2) + 19, " ///          \\\\\\         ///          \\\\\\", curses.color_pair(1))
    stdscr.addstr(18, ((curses.COLS - 1) // 2) + 19, " \\\\\\          ///         \\\\\\          ///", curses.color_pair(1))
    stdscr.addstr(19, ((curses.COLS - 1) // 2) + 19, "    \\\\\\    ///               \\\\\\    ///", curses.color_pair(1))
    stdscr.addstr(20, ((curses.COLS - 1) // 2) + 19, "       \||/                     \||/", curses.color_pair(1))
    stdscr.addstr(25, (230 // 2) - len("Welcome To DankBot v0.1") - 4, "Welcome To DankBot v0.1", curses.color_pair(3))
    stdscr.addstr(26, (230 // 2) - len("Press Any Key To Continue") - 3, "Press Any Key To Continue", curses.color_pair(4))
    stdscr.getch()
    stdscr.clear()
    stdscr.refresh()
    stdscr.addstr(0, 0, "IMPORTANT INSTRUCTIONS", curses.color_pair(5))
    stdscr.addstr(1, 10, "1. As soon as the program starts a chrome window will open up with the discord login page.", curses.color_pair(2))
    stdscr.addstr(2, 10, "2. Login by QR or Login using password and email. We do not retain the data in any manner.", curses.color_pair(2))
    stdscr.addstr(3, 10, "3. Select the channel where you want the bot to do its work.", curses.color_pair(2))
    stdscr.addstr(4, 10, "4. Make sure there isn't any spam bot detector and you have the permissions.", curses.color_pair(2))
    stdscr.addstr(5, 10, "5. After all the above steps are done type in \"startprogram\" in console to start the bot", curses.color_pair(2))
    stdscr.addstr(6, 10, "6. To Stop The bot close the browser then the console or just type in \"killbot\"", curses.color_pair(2))
    stdscr.addstr(20, 10, "Press Any Key To Activate The Program", curses.color_pair(2))
    stdscr.getch()
    bot = DankBot()
    process = Thread(target=bot.start_thread)
    process.start()
    time.sleep(4)
    stdscr.clear()
    stdscr.refresh()
    stdscr.addstr(0, 0, "Enter \"startbot\" to start the application: ", curses.color_pair(5))
    s = stdscr.getstr(4, 0, 15)
    stdscr.addstr(2, 0, s, curses.color_pair(2))
    bot.start_bot()
    stdscr.clear()
    stdscr.refresh()
    stdscr.addstr(0, 0, "Enter \"killbot\" to stop the application:    ", curses.color_pair(5))
    s = stdscr.getstr(5, 0, 5)
    stdscr.addstr(2, 0, s, curses.color_pair(2))
    bot.terminate()
    stdscr.clear()
    stdscr.refresh()
    stdscr.addstr(0, 0, 'Please Wait Ending All Processes.....', curses.color_pair(2))
    while(bot.status != 'Ended'):
        pass
    stdscr.clear()
    stdscr.refresh()
    stdscr.addstr(0, 0, "Thank You For Using DankBot", curses.color_pair(1))
    stdscr.getch()

def run_bot():
    wrapper(main)



from selenium import webdriver
from selenium.webdriver.common.keys import Keys
import time
class DankBot():
    """
    DankBot Class Initialises the Headless browser followed by the necessary automation fucntionalities.
    Controls the curses inlay.
    """
    TYPE_BOX = 'markup-2BOw-j.slateTextArea-1Mkdgw.fontSize16Padding-3Wk7zP'
    BASE_URL = 'https://discord.com/login'
    DEF_BROWSER = "Chrome"
    driver = ''
    _running = False
    status = 'initiated'

    def __init__(self, def_brow='Chrome'):
        self.DEF_BROWSER = def_brow
        self._running = False

    def start_thread(self):
        self._running = False
        self.driver = webdriver.Chrome()
        self.driver.get(self.BASE_URL)
        self.exec_base_script()

    def terminate(self):
        self._running = False

    def start_bot(self):
        self._running = True

    def exec_base_script(self):
        while(not self._running):
            pass
        self.status = 'Working'
        while(self._running):
            self.type_box = self.driver.find_element_by_class_name(self.TYPE_BOX)
            self.type_box.send_keys('pls beg')
            self.type_box.send_keys(Keys.ENTER)
            time.sleep(5)
            self.type_box.send_keys('pls hunt')
            self.type_box.send_keys(Keys.ENTER)
            time.sleep(5)
            self.type_box.send_keys('pls dig')
            self.type_box.send_keys(Keys.ENTER)
            time.sleep(5)
            self.type_box.send_keys('pls fish')
            self.type_box.send_keys(Keys.ENTER)
            time.sleep(5)
            self.type_box.send_keys('pls deposit all')
            self.type_box.send_keys(Keys.ENTER)
            time.sleep(3)
            self.type_box.send_keys('pls use horseshoe')
            self.type_box.send_keys(Keys.ENTER)
            time.sleep(5)
            try:
                self.type_box.send_keys('pls search')
                self.type_box.send_keys(Keys.ENTER)
                time.sleep(3)
                options = self.driver.find_elements_by_class_name('container-1v9gV9')
                q = options[-1].find_elements_by_tag_name('button')
                for i in range(len(q)):
                    if q[i].text == 'Vacuum':
                        to_click = i
                        break
                    elif q[i] in ['Basement', 'Bus', 'Car', 'Coat', 'Dresser', 'Fridge', 'Pocket', 'Washer']:
                        to_click = i
                    else:
                        to_click = i
                q[i].click()
            except IndexError as error:
                print("Error")
            time.sleep(10)
            try:
                self.type_box.send_keys('pls highlow')
                self.type_box.send_keys(Keys.ENTER)
                time.sleep(5)
                options = self.driver.find_elements_by_class_name('container-1v9gV9')
                description = self.driver.find_elements_by_class_name('grid-1nZz7S')[-1]
                print(description.text)
                number = int(description.text.split()[21][:-1])
                print(number)
                if 100 - number < number - 0:
                    choice = 0
                    print('Higher')
                else:
                    choice = 2
                    print('Lower')
                q = options[-1].find_elements_by_tag_name('button')
                q[choice].click()
                time.sleep(3)
            except IndexError as error:
                time.sleep(5)
            time.sleep(15)
        self.status = 'Ended'



from distutils.core import setup
from setuptools import find_packages

with open('requirements_dev.txt') as req:
    requirements = req.readlines()

setup(
    name='DiscordDankBot',         
    packages=find_packages(),
    version='0.1',     
    license='MIT',        
    description='All in one bot to manage your dankmemer account. Easy automaton for grinding money and collectables.',  
    author='Adithya Narayan',                  
    author_email='narayanadithya1234@gmail.com',     
    entry_points={'console_scripts': ['dankbot = dankbot.dankcli:run_bot']},
    url='https://github.com/NarayanAdithya/Dankbot',   
    download_url='https://github.com/NarayanAdithya/Dankbot/archive/refs/tags/v_0.1-beta.tar.gz',    
    keywords=['Discord', 'Automation', 'DankBot', 'Dank Memer'],  
    install_requires=requirements,
    classifiers=[
        'Development Status :: 4 - Beta',     
        'Intended Audience :: Developers',      
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',  
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9'
    ],
)
